package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;

import com.yunzhi.inte.entity.Store;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.FoodIngredients;
import com.yunzhi.inte.service.FoodIngredientsService;

/**
 * 菜肴食材;(food_ingredients)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "菜肴食材对象功能接口")
@RestController
@RequestMapping("/")
public class FoodIngredientsController extends BaseController {

    @Autowired
    private FoodIngredientsService foodIngredientsService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/foodIngredients/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(foodIngredientsService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/foodIngredients")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                             @ApiParam("食材ID") @RequestParam(value ="dishId") Integer dishId) throws Exception {

        IPage<Store> pg = new Page<>(pageNum, pageSize);
        IPage<Store> result = foodIngredientsService.getByDish(pg, dishId);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param foodIngredients 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/foodIngredients")
    public ResponseBean add(@ApiParam("实例对象") @RequestBody FoodIngredients foodIngredients) throws Exception {

        QueryWrapper<FoodIngredients> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("dish_id", foodIngredients.getDishId());
        queryWrapper.eq("item_id", foodIngredients.getItemId());
        int count = foodIngredientsService.count(queryWrapper);

        if (count > 0) {
            return ResponseBean.error("当前菜肴已存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        foodIngredientsService.save(foodIngredients);
        return ResponseBean.success(foodIngredients);
    }


    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/foodIngredients/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        foodIngredientsService.removeById(id);
        return ResponseBean.success("success");
    }
}