package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ExcelUtils;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Store;
import com.yunzhi.inte.service.StoreService;

import javax.servlet.http.HttpServletResponse;

/**
 * 库存表;(store)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "库存表对象功能接口")
@RestController
@RequestMapping("/")
public class StoreController extends BaseController {

    @Autowired
    private StoreService storeService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/store/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(storeService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/store")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                             @ApiParam("名称") @RequestParam(value ="name", required = false) String name,
                             @ApiParam("分类ID") @RequestParam(value ="typeId", required = false) String typeId,
                             @ApiParam("是否食材") @RequestParam(value ="isDish", required = false) Integer isDish) throws Exception {

        IPage<Store> pg = new Page<>(pageNum, pageSize);
        IPage<Store> result = storeService.getPageBy(pg, name, typeId, isDish);

        return ResponseBean.success(result);
    }


    /**
     * 导出
     *
     * @param name 名称
     * @param typeId 分类ID
     * @return 导出
     */
    @ApiOperation("导出")
    @GetMapping("/store/export")
    public ResponseBean export(@ApiParam("名称") @RequestParam(value ="name", required = false) String name,
                               @ApiParam("分类ID") @RequestParam(value ="typeId", required = false) String typeId,
                               HttpServletResponse response) throws Exception {

        List<Store> result = storeService.getListBy(name, typeId);

        ExcelUtils.flush(response, Store.class, result, "库存列表");

        return null;
    }

    /**
     * 新增数据
     *
     * @param store 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/store")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Store store) throws Exception {
        Store origin = storeService.getExistBy("name", store.getName(), false, true);
        if (null != origin) {
            return ResponseBean.error("当前名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        store.setStatus(1);
        storeService.save(store);
        return ResponseBean.success(store);
    }

    /**
     * 更新数据
     *
     * @param store 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/store/{id}")
    public ResponseBean edit(@ApiParam("对象ID") @PathVariable Integer id,
                             @ApiParam("对象实体") @RequestBody Store store) throws Exception {
        Store origin = storeService.getExistBy("name", store.getName(), false, true);
        if (null != origin && !id.equals(origin.getId())) {
            return ResponseBean.error("当前名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        store.setId(id);
        storeService.updateById(store);
        return ResponseBean.success(store);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/store/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        storeService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}